summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmdiscedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmdiscedit.h')
-rw-r--r--kpovmodeler/pmdiscedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmdiscedit.h b/kpovmodeler/pmdiscedit.h
index 5ce4d111..73466f32 100644
--- a/kpovmodeler/pmdiscedit.h
+++ b/kpovmodeler/pmdiscedit.h
@@ -33,12 +33,13 @@ class PMDisc;
class PMDiscEdit : public PMGraphicalObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMGraphicalObjectEdit Base;
public:
/**
* Creates a PMPlaneEdit with parent and name
*/
- PMDiscEdit( TQWidget* parent, const char* name = 0 );
+ PMDiscEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -33,12 +33,13 @@ class PMDisc;
public:
/**
- * Creates a PMPlaneEdit with parent and name
+ * Creates a PMPlaneEdit with tqparent and name
*/